==> webgen-0.81.tgz: webgen-0.81/process.php <==
<?php 
 require("user.php");
 require($configfile);
 require("dbconfig.php");
 /**** @ܼ ********/
 $user=$_REQUEST["user"];
 $process=$_REQUEST["process"];
 $key=$_REQUEST["key"];
 $dodel=$_REQUEST["dodel"];
 $ptab=$_REQUEST["ptab"];
 $pname=$_REQUEST["pname"];
 $ctlfile=$_REQUEST["ctlfile"];
 $target=$_REQUEST["target"];
 $vuser=$_REQUEST["vuser"];
 $boards=$_REQUEST["boards"];
 $remark1=$_REQUEST["remark1"];
 $remark2=$_REQUEST["remark2"];
 $remark3=$_REQUEST["remark3"];
 $LIMIT=$_REQUEST["LIMIT"];
  //TableXSOѼ
 $tabout="border=1";
  //d߳浧ƪY
  //C@
 $PGNUM=20;
 // Primary Key	
 $PKEY="aid";
 $RETADD="listmain.php?$user";
 /***** {ҥΨ **********/
 $OBJ=$key;
 require("auth.php");
 /****** O޲z̪ܴNಣ *******/
 if (!in_array($PHP_AUTH_USER,$MANAGER))
 {
        echo "KKI$PHP_AUTH_USER AO޲z̡AMoӥ\I<br>";
        exit;
 }

 $DAYTIME=date("Y~mdH:i:s");
  /****BzJܼ*****/
  if (get_magic_quotes_gpc()==0)
  {
	$ptab=addslashes($ptab);
	$pname=addslashes($pname);
	$ctlfile=addslashes($ctlfile);
	$target=addslashes($target);
  }
  //INSERTO
  $INSERT="insert into main values ('$ptab','$pname','$ctlfile','$target','$PHP_AUTH_USER','$REMOTE_ADDR','$DAYTIME','$vuser','$boards','$remark1','$remark2','$remark3')"; 
  //DELETEO
 $LIMIT=stripslashes($LIMIT);
 $DELETE="delete from main where ".$LIMIT;
 if (strcmp($process,"sW")==0) // insert
 {
   if ($dodel==1) //ݭnR
   	{
		$result=db_exec($db_conn,$DELETE);
		if (!$result){
			echo "ƧR~AO $DELETE !";
			exit;
		}
	}
   
   $result=db_exec($db_conn,$INSERT);
   if (!$result){
	echo "ƷsW~AO $INSERT !";
	exit;
   }
  if ($dodel==0) //Ĥ@sW
  {
   /****} ******/
   $PRJ=join( "", file( "prj.cfg" ) );
   $PRJ=str_replace("%name%",$ptab,$PRJ);
   for ($i=0;$i<count($MANAGER);$i++)
       $PRJ=$PRJ." grant all on $ptab to $MANAGER[$i];";
   $PRJ=$PRJ." grant all on $ptab to $WRITER;";
   /******o̴Nn}v writerF ********/
   //echo "PRJ=$PRJ<br>";
   $result=db_exec($db_conn,$PRJ);
   if (!$result){
	echo "MƷsW~AO $PRJ !";
	exit;
   }
   /******إߥؿ******/
   if (!mkdir($BASEDIR.$target,0755))
   	{
	  echo "}ұMؿ~AؿWrO $BASEDIR$target!";
	  exit;
	}
   }
	echo "<a href=\"$RETADD\">J\IB}I</a>\n";
 	exit;
 }
 /*****  R ********/
 if (strcmp($process,"R")==0) //DELETE 
 {
   $QUERY="select target from main where ptab='$key'";
   $res=db_exec($db_conn,$QUERY);
   $AROW=db_fetch_row($res,0);

   $LIMIT="ptab='$key'";
   $DELETE="delete from main where ".$LIMIT;
   $result=db_exec($db_conn,$DELETE);
   if (!$result){
	echo "ƧR~AO $DELETE !<br>\n";
	exit;
   }
   $DELETE="drop table $key";
   $result=db_exec($db_conn,$DELETE);
   if (!$result){
	echo "ƧR~AO $DELETE !<br>\n";
	exit;
   }
        /***** RMɡA]KMӥؿ \Ȯɨ******/
       /*****************************
        $GB=$GBBASEDIR.trim($AROW[0]);
        $IMG=$upload_dir.trim($AROW[0]);
        $MN=$BASEDIR.trim($AROW[0]);
        exec("/bin/rm -rf ".$GB);
        exec("/bin/rm -rf ".$IMG);
        exec("/bin/rm -rf ".$MN);
	***********************************/
        db_freeresult($res);
	echo "<a href=\"$RETADD\">R\IB}I</a><br>\n";
        exit;
 }
 /*****  ק ********/
 $LIMIT="ptab='$key'";
 $EDIT="select ptab,pname,ctlfile,target,vuser,boards,remark1,remark2,remark3 from main where ".$LIMIT;
 if (strcmp($process,"ק")==0) //EDIT 
 {
   $result=db_exec($db_conn,$EDIT);
   if (!$result){
	echo "ƭק~AO $EDIT !";
	exit;
   }
   $numrow=db_NumRows($result);  
   $ARAW=db_fetch_row($result,0); //Ū@O
   /****} ******/
   $fcfg=fopen("main.cfg","r");
   $cnt=0;
   $PAT="%DATA";
   while (!feof($fcfg)) 
      {
         $temp=fgets($fcfg,256);
 	 if (strstr($temp,$PAT))
         {
		$temp=str_replace($PAT,$ARAW[$cnt],$temp);
		$cnt=$cnt+1;
	 } elseif (strstr($temp,"%LIMIT"))
	 {
		$temp=str_replace("%LIMIT","<input type=\"hidden\" name=\"LIMIT\" value=\"$LIMIT\">",$temp);
	 } elseif (strstr($temp,"%user%"))
		$temp=str_replace("%user%",$user,$temp);
	 echo $temp;
      }
   fclose($fcfg);
        exit;
 }
?>

==> webgen-0.93.tgz: webgen-0.93/process.php <==
<?php 
 require("user.php");
 require($configfile);
 require("dbconfig.php");
 /**** @ܼ ********/
 $user=$_REQUEST["user"];
 $process=$_REQUEST["process"];
 $key=$_REQUEST["key"];
 $dodel=$_REQUEST["dodel"];
 $ptab=$_REQUEST["ptab"];
 $pname=$_REQUEST["pname"];
 $ctlfile=$_REQUEST["ctlfile"];
 $target=$_REQUEST["target"];
 $vuser=$_REQUEST["vuser"];
 $boards=$_REQUEST["boards"];
 $remark1=$_REQUEST["remark1"];
 $remark2=$_REQUEST["remark2"];
 $remark3=$_REQUEST["remark3"];
 $LIMIT=$_REQUEST["LIMIT"];
  //TableXSOѼ
 $tabout="border=1";
  //d߳浧ƪY
  //C@
 $PGNUM=20;
 // Primary Key	
 $PKEY="aid";
 $RETADD="listmain.php?$user";
 /***** {ҥΨ **********/
 $OBJ=$key;
 require("auth.php");
 /****** O޲z̪ܴNಣ *******/
 if (!in_array($PHP_AUTH_USER,$MANAGER))
 {
        echo "KKI$PHP_AUTH_USER AO޲z̡AMoӥ\I<br>";
        exit;
 }

 $DAYTIME=date("Y~mdH:i:s");
  /****BzJܼ*****/
  if (get_magic_quotes_gpc()==0)
  {
	$ptab=addslashes($ptab);
	$pname=addslashes($pname);
	$ctlfile=addslashes($ctlfile);
	$target=addslashes($target);
  }
  //INSERTO
  $INSERT="insert into main values ('$ptab','$pname','$ctlfile','$target','$PHP_AUTH_USER','$REMOTE_ADDR','$DAYTIME','$vuser','$boards','$remark1','$remark2','$remark3','')"; 
  //DELETEO
 $LIMIT=stripslashes($LIMIT);
 $DELETE="delete from main where ".$LIMIT;
 if (strcmp($process,"sW")==0) // insert
 {
   if ($dodel==1) //ݭnR
   	{
		$result=db_exec($db_conn,$DELETE);
		if (!$result){
			echo "ƧR~AO $DELETE !";
			exit;
		}
	}
   
   $result=db_exec($db_conn,$INSERT);
   if (!$result){
	echo "ƷsW~AO $INSERT !";
	exit;
   }
  if ($dodel==0) //Ĥ@sW
  {
   /****} ******/
   $PRJ=join( "", file( "prj.cfg" ) );
   $PRJ=str_replace("%name%",$ptab,$PRJ);
   for ($i=0;$i<count($MANAGER);$i++)
       $PRJ=$PRJ." grant all on $ptab to $MANAGER[$i];";
   $PRJ=$PRJ." grant all on $ptab to $WRITER;";
   /******o̴Nn}v writerF ********/
   //echo "PRJ=$PRJ<br>";
   $result=db_exec($db_conn,$PRJ);
   if (!$result){
	echo "MƷsW~AO $PRJ !";
	exit;
   }
   /******إߥؿ******/
   if (!mkdir($BASEDIR.$target,0755))
   	{
	  echo "}ұMؿ~AؿWrO $BASEDIR$target!";
	  exit;
	}
   }
	echo "<a href=\"$RETADD\">J\IB}I</a>\n";
 	exit;
 }
 /*****  R ********/
 if (strcmp($process,"R")==0) //DELETE 
 {
   $QUERY="select target from main where ptab='$key'";
   $res=db_exec($db_conn,$QUERY);
   $AROW=db_fetch_row($res,0);

   $LIMIT="ptab='$key'";
   $DELETE="delete from main where ".$LIMIT;
   $result=db_exec($db_conn,$DELETE);
   if (!$result){
	echo "ƧR~AO $DELETE !<br>\n";
	exit;
   }
   $DELETE="drop table $key";
   $result=db_exec($db_conn,$DELETE);
   if (!$result){
	echo "ƧR~AO $DELETE !<br>\n";
	exit;
   }
        /***** RMɡA]KMӥؿ \Ȯɨ******/
       /*****************************
        $GB=$GBBASEDIR.trim($AROW[0]);
        $IMG=$upload_dir.trim($AROW[0]);
        $MN=$BASEDIR.trim($AROW[0]);
        exec("/bin/rm -rf ".$GB);
        exec("/bin/rm -rf ".$IMG);
        exec("/bin/rm -rf ".$MN);
	***********************************/
        db_freeresult($res);
	echo "<a href=\"$RETADD\">R\IB}I</a><br>\n";
        exit;
 }
 /*****  ק ********/
 $LIMIT="ptab='$key'";
 $EDIT="select ptab,pname,ctlfile,target,vuser,boards,remark1,remark2,remark3 from main where ".$LIMIT;
 if (strcmp($process,"ק")==0) //EDIT 
 {
   $result=db_exec($db_conn,$EDIT);
   if (!$result){
	echo "ƭק~AO $EDIT !";
	exit;
   }
   $numrow=db_NumRows($result);  
   $ARAW=db_fetch_row($result,0); //Ū@O
   /****} ******/
   $fcfg=fopen("main.cfg","r");
   $cnt=0;
   $PAT="%DATA";
   while (!feof($fcfg)) 
      {
         $temp=fgets($fcfg,256);
 	 if (strstr($temp,$PAT))
         {
		$temp=str_replace($PAT,$ARAW[$cnt],$temp);
		$cnt=$cnt+1;
	 } elseif (strstr($temp,"%LIMIT"))
	 {
		$temp=str_replace("%LIMIT","<input type=\"hidden\" name=\"LIMIT\" value=\"$LIMIT\">",$temp);
	 } elseif (strstr($temp,"%user%"))
		$temp=str_replace("%user%",$user,$temp);
	 echo $temp;
      }
   fclose($fcfg);
        exit;
 }
?>
